NavigationActionPolicy class

Class that is used by WebView.shouldOverrideUrlLoading event. It represents the policy to pass back to the decision handler.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited
toValue() → int

Operators

operator ==(Object value) → bool
The equality operator.
override

Constants

ALLOW → const NavigationActionPolicy
Allow the navigation to continue.
CANCEL → const NavigationActionPolicy
Cancel the navigation.