FontButtons class

Font group

Inheritance

Constructors

FontButtons({bool bold = true, bool italic = true, bool underline = true, bool clearAll = true, bool strikethrough = true, bool superscript = true, bool subscript = true})
const

Properties

bold → bool
final
clearAll → bool
final
hashCode → int
The hash code for this object.
no setterinherited
italic → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strikethrough → bool
final
subscript → bool
final
superscript → bool
final
underline → bool
final

Methods

getIcons1() → List<Icon>
getIcons2() → List<Icon>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited